/**
 * Copyright 2023 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.flutter.plugins.pay_android.view

import android.content.Context
import android.util.Log
import android.view.View
import android.widget.Button
//import com.google.android.gms.wallet.button.ButtonOptions
//import com.google.android.gms.wallet.button.PayButton
import io.flutter.plugin.platform.PlatformView
import org.json.JSONArray
import org.json.JSONObject


internal class PayButtonView(context: Context, id: Int, creationParams: Map<String?, Any?>?) : PlatformView {
    //private val payButton: PayButton
    private val payButton: Button

    init {
        val allowedPaymentMethods = JSONArray().put(cardPaymentMethod())

        payButton = Button(context)
        payButton.text = "RAFIF!"
        payButton.isEnabled = false
        //payButton = PayButton(context)
        //payButton.initialize(ButtonOptions.newBuilder().setAllowedPaymentMethods(allowedPaymentMethods.toString()).build())
    }

    override fun getView() = payButton

    override fun dispose() = Unit

    private val allowedCardNetworks = JSONArray(listOf(
        "AMEX",
        "DISCOVER",
        "JCB",
        "MASTERCARD",
        "VISA"))

    private val allowedCardAuthMethods = JSONArray(listOf(
        "PAN_ONLY",
        "CRYPTOGRAM_3DS"))

    private fun baseCardPaymentMethod(): JSONObject {
        return JSONObject().apply {

            val parameters = JSONObject().apply {
                put("allowedAuthMethods", allowedCardAuthMethods)
                put("allowedCardNetworks", allowedCardNetworks)
                put("billingAddressRequired", true)
                put("billingAddressParameters", JSONObject().apply {
                    put("format", "FULL")
                })
            }

            put("type", "CARD")
            put("parameters", parameters)
        }
    }

    private fun gatewayTokenizationSpecification(): JSONObject {
        return JSONObject().apply {
            put("type", "PAYMENT_GATEWAY")
            put("parameters", JSONObject(mapOf(
                "gateway" to "example",
                "gatewayMerchantId" to "exampleGatewayMerchantId"
            )))
        }
    }

    private fun cardPaymentMethod(): JSONObject {
        val cardPaymentMethod = baseCardPaymentMethod()
        cardPaymentMethod.put("tokenizationSpecification", gatewayTokenizationSpecification())

        return cardPaymentMethod
    }
}